/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvSignalVar.h"
#include "HvSignalEnvelope.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvControlCast.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_GolTqN8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3wzjlHnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xPBshk3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Ea8jtft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J2pexcm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LcJkYQU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jiswgFzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nUW4OzR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cryBKJKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DFGY6rTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JxrsLTg7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NLwMXtIe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VeoMQZLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZWPOyy8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1ud3xcc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6aw5Wh64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WJNpXwDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PNRvgaFo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u8WMy3kr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JzgJO8lJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5qj7MFjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_u1586xG0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_1apiTbgz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NB8pwKxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bCWDqjco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8KrZF3Uh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uRUSMeUO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JVCbRCEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cHqnMh7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aD73Xtgl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7QpXL5GD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_9O3RFjCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YOnCEP0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ZwpLA1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2DonJL4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G4JSRepS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W7vfgkya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OddebPCp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ir78NOwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RxSmSPVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oK46jnhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GHE7t0yx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ljHjhB5p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MK394EZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0un4s8pw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_WUe15rzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2QrXNj0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Xk9701w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_89BeoITJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X6fpzKzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TwjxiO6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7fN8WSHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UcqBdWJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lo5Y2SPv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tJsaHfP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zLiDg7OH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_usSogwuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5ZYiit4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8TXlW3Rj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_VJHPczzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YdRRCc8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EusvZEWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YlRCBhUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BHl7OvrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5qvBLdQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GbD0YsLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yGx6C8dj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GmtUDWY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fniRX0FQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oQjLOQeo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9lCE5FTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_icDI9pIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5BHdAb2n_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_LuC4oNvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GmrexnlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ASZUoazc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ykm90Vki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rlnsm7fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z5sjwbT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PbxUtEPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zfUDGKbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SjGmO9CT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iMZwxm5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7F54PR4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xfS1A1QO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_brsBQVlD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_W8OaEA9i_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_6RdvY1AW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ynNeb7tL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wExabmXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dMwcjD1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PL0eWPY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5auCCmDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rlSuvwAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yv1xVgq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z94mV37Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3CXNIKcZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xzcx7w7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vbAGjMbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZR5fWeuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_z2tETFvo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_fdxuKjFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2zTC9ezs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6k8jJsV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iYBl5r1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W33YeGsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WkuCAdod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EbZas6cg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wn0Tnnzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3pwZvrzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vfmeuNQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AqWXdEVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tkMyN4bg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aVzV4Ejw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1yzDLZsu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_t8mmlHdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FBU1B8hB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nftg7njj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sIlEMpNw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mcuWLXXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bNY9TZ0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AKkOg8dz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vsDDxrbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MKmKK2Bl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DTFmLSdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a9C6aHL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vVLUkwN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oqBBH3c2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3CoPfw2X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_BbH9lfgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LmEJ9qeo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JQLJ7JL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yWW5MAUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_halTL7YE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lw1lbMTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jE1EY0De_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xkyKiZln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pPX4MRSD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4ZPGCOmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zRzm4PnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EYUmGTxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jYQ82juX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NAqTQASI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_mZ1ZfXFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b8eW82h5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hTbKsiL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wlICd6vW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FIRrxugn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NwJ6d78m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T2BbT8fX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZBKZq96Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MnDPQBzz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F88PbBx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nb7MhTtA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QjDMD4k7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0zdEGx5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6IZl2bUK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_bvjTMH23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hPZl1Ajc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YpJLpQHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JYlIKYqk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C6GcXIdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0azaCDMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i8NBcdi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SaM2wHag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yf0Wal59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x99vWHtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W9Rhh5H9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qqQVZm6M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6QrISNTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_01gUArrW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_5URasD5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D5FOq16x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kru5AXhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5h35QAFa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bhovpW3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uuM12vaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8oITiUEI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZsarVCpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pH80Rk50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YsA5Gjhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KTapLssu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ul9JqanZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_weZE6TV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TmNvSBFQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_eYdBYwKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sACsfBHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9zg3m8Od_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1z5aUl3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eru9sGdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2G3RUEgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BZ4PfYS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sf173qzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1i0xgwx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MSi0z9Cx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ILRp84J1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tfutJNfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mp6bDJxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jDhU8Z7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qBuZEXM3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_40rjpPRe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8smaO9ZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_evBR6Xrw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZWhGMsCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rsu5eGGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cNaC56my_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wc0Vv7Bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3NyHH7Sl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YZsFIq5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kL0ixBu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TBnfcYk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JnAZb9Wo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kSHcaQuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hNBY6TDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xzBKIjCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V0BhAQpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_agMzAP8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lJDamGUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fyd7QV0Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cGSYnDmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5oFVpgAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e2IMPjG7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s915bon3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JQ3TgHdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dflxXvDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_czWJrvSD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kDCBwMtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XFPK8k5a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XMx6dFCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wAahy0HA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lK4aJWKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AIEQDun7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_moDAbnBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FGwuOquo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ASDPeSVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lVt1zAow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gJKxILkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oTo3SWOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Py9itYaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VqOGhWN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B5VggnlA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_X1K4FmD0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sVa4tm62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K2SoT8XX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EOFnaJJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QaT0GdsJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LlTDdSVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5SCO2kUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6afOwbEP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_10ZPC4Br_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1ovYnhkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yGq1DcEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YTkBzE4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0ZYeIsC5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vB6yra9H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ftKj1so3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jRADr5Wv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Jc2cxcwz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_unAPKUWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dMLtm9lc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_t0ixtZqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qdwphRQg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RifrG4Yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HRyUYze1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fxevt2lg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LUbmsTbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fY8z4I0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WHuH8Gib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_z5kG4mWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_dTpUJqTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cYUuML26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kykY7jMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y4pYGs0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w2VpcfWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qx2WnN2P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FAOrEDtY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1NgKv6VO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p7BzDptS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uYZtDsmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cdZCjlZ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hEeVqeyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wWoCetCZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jcTiqM4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YW8V4Sk3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xPOwjUYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XtGs1Kns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CCzsHmJc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C4juarrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_svDL8a9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qmajW5lR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6mSlu1pL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YoJeJPyj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LGrcIoHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g81xz6ci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rI6XtsFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Um28SwZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0e6kYkzn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zw0qsyGY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IiwQtMmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FMmZn9FI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YR8Sgf1w_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_J7K3eYHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B4Tmy79o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mpvYSj1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nblxbgh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LDkVUh2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7mSQqvbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IGQyEmBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_geSxqYMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_osimkXqY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_3XEkPbXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sZwt6R0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CldvHgnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UAaMJvrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6QLNRPfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HEsqPnVa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_633QbyLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zByTKCns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CDjg2Pf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hriBAIXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1CfBqnPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XYnsPUsm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Cgd9W5uF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EzFnwV2r_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_s8n0VvhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KETmwvAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U8OCyoY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_02rodNzI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iIQfYD6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cK37IPci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hn6xJOmW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r2s0gmsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ysZhSnMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gceamlip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wbwwPGZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KxgyOh6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DWI3pe6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GTP68znY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_PiUkLyXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ouA8YrQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g3W3fsYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JhvQiDkd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wR1FTbS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ks09Dhgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x2YPvfcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GJFopR5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fyk3Yuib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2trtA1Lt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KoUZ2Xhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lt101e7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fO2pj04m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZddO5hZV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_u1jXOVaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aPD9tvt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lqAhInOl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DjwffKBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_swj0To6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_exyPZfh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ad89OrYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_04jHeTQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qrip1jLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SSgn1kFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0yW2buwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_s3QFvXaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gTsnpLLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lRBbbxnA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_8V3WilE2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uvsY8tuX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GTMXv85w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ue9KezGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eE6SxkRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OL78md1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hlV1deJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RMYJO6Pf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UDK140jZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P7ba8Fx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HkK9eut5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fIpQUbM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KfNOQGYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wAVGp6Xi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_HCxv6qYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FFSaPw5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GPqhsCFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yNXeg9xi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ArAd3XTo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9tAUieF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N1D1i75J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TssAZcGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kGYP4wLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jyFsGj1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rhWoVTAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CdeB4vAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_St0tPgOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oqIdPVly_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_du0IdDIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_efomWyhT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XRUIw2L4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yrWPp6IR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3JyAHPr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UOhB5KOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4WuUeTbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nDZCOF3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FTp3HI7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_geIZFF99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rLIlYtqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jDabV6J1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jYwEwF9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KmEhJ3BE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_fKDEPpe5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uMjypQh5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tVU3Bg5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w7xGtC3Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G8pDnSJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_axxTUe5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8vL1JMEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v73CO2Hj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SIn0FT1x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h1Mr2uGp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2g06Y689_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lpNk0EXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_X7TfjCBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1SckbTFi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_UvT6Vp3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PaKHIdOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dIpk4oYF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qt7X7kvc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rW68GGZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MWVJNHXW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n8k6feDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Him72Qyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N2Uqf9ST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PRwRKej8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5LplzYxc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_u7KpzmAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LeOVcIHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6rrJsjlQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_miqvAJwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wsvD7Y0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cr72RIWO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_So1iOg2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N9Ogq9fM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qa1PwlY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gh3lguCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lp0LKdzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S1CruXJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wup7pJtN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LW4coVUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QGthaGGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Qz2KygHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3Hi9GSzs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7XlVqGA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BNsONRcb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jlc9tN0I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V934B46d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lmIJR8r3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xhtv2fJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3GGNQHRL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YX6lxk7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dlHGB27H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_liSVFSfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U2jzOkXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xcGe1OPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Rm01cPRO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5iZOOLcZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_k8I9mE2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xc1hXpho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DS1xCN5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sUZSgngW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pdkv8bvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KerHg32X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_914mf1ce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mMu2qtdm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_25ccdIC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dyXbrGmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tz10BdLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RGDppBTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zWD1zpIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aO55ixTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2qWfsJph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BfNDc4Ii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qaiVRXZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l1uijWcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fo5rrgJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oyFcIXKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LQvIwzhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KUvYqkme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7TWdW8W1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AWVKC8Uk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yWSZTSXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jdZQ8r2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8W1HRP82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kSiJrTQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EP4QiHkl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dJxbY3Qz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZE3QK9Cb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pn9E8bSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LtQ8WSX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_maHzGNjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m98OWYDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_04o8TVz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1gGW8iIx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B7wjID5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nonz2zTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DZ4jWTFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wbfVKPYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cDMT6xyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MXVsR4qr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qjxQWd6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VYmKsHUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t74wr3lb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1EaqcJ7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LYB3SZpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDbsAbkB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bCjIXen3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kjwtgTbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mqwYIbRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r2ng4u9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kd0CsLsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_deXxS8Vq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CGkO0xNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dq42GRCU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jyYKCHSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hkPcOrg4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Iev3Qeq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MvGz7FwV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LoClgciz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KGMX23fe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vgKig6N5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_c5EBjN27_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ioO9oTZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_01gJucX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0cGaXWmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YuOIaP47_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zMvcR9m3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iIjy3gqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oM1rs3ze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sEwphSnT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ufqj8Qpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HfWwDtXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XsRdPvJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mziOE4QU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dhPbYCzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nQoxq4mc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bIaxUBLK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MFyIg3Y5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OvnJrEfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fDY0ueC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_BPK2PezG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_z0gYwpjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ThUc6uW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PBr80Ni8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xAg77AyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tMSLJYDr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ttAnZBRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dFvO3Lwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2fbFj1D7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PUZIzID6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y5jr7FOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lv7dJlY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YzAKvw9e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rVlvp7XN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jJFoToO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7dlbICKt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8t3H2jBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hZ7w4ev4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bwrTTCFg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_muuklgMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s0w7L1Oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1LniQsex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fEWcskBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LLL5VXaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b6nui80F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gM9UP19Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HuLKtyrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ql57B5RY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oFVyRbG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aFmyisvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SDwT3eRx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XdQ2cTRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ij1HUBJk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2ixHdDko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IUSvkOm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xvvdKEtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V0GfCozM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wdI0RgtX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vK4R15ID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hEj92E5y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yyDEfytq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OwZEYBxc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FjXmTUBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XwfsbYXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gssWcTvV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y0z4O6zX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tT90hpQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4e9ueaY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yrVjI7fG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cKqUtYj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_t3ElHYV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BrvpHost_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8CpNk7UX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gFAdNmvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gVOclxZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mkIKJYlH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dVhEr0PJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6K15Xr9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FVPm3o9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MX434jCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5s6yALMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Nf2Idi3n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CU38V6wk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yq0obu3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uSSMXVnG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uc0TFB7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GD6UG4eU_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_7QdTuCyK;
  SignalLine sLine_bfyAvs8n;
  SignalLine sLine_GSNMmdQj;
  SignalLine sLine_RCr9WmBH;
  SignalLine sLine_XNVbNKcB;
  SignalLine sLine_b2XXVnX6;
  SignalLine sLine_QmVUPE3M;
  SignalLine sLine_IZVBTRZZ;
  SignalLine sLine_HcZn2YRe;
  SignalLine sLine_C3fhADNu;
  SignalLine sLine_aW2sooWe;
  SignalLine sLine_GCpU2o8u;
  SignalEnvelope sEnv_z5kG4mWN;
  SignalEnvelope sEnv_dTpUJqTm;
  SignalLine sLine_OrgfNzxO;
  SignalLine sLine_a2NXECCt;
  SignalLine sLine_PEdHdOhj;
  SignalLine sLine_TDNXfMPO;
  SignalLine sLine_AT31RMNa;
  SignalLine sLine_ljgnVXoh;
  SignalLine sLine_159VfxCB;
  SignalLine sLine_twMeG4V8;
  SignalLine sLine_fYgyUPwU;
  SignalLine sLine_kiSijYRw;
  SignalLine sLine_5PzvjFr5;
  SignalLine sLine_thZ50IZE;
  SignalLine sLine_0gg3fXD5;
  SignalLine sLine_VTBoo2xA;
  SignalLine sLine_8jE1x9u4;
  SignalLine sLine_kakFBtiE;
  SignalLine sLine_WjrvsioR;
  SignalLine sLine_frDinQET;
  SignalEnvelope sEnv_BPK2PezG;
  SignalEnvelope sEnv_z0gYwpjd;
  SignalLine sLine_QyJhiZr5;
  SignalLine sLine_1jVGjqKD;
  SignalLine sLine_mfusku04;
  SignalLine sLine_jGWCXF4R;
  SignalLine sLine_pqrGIDBx;
  SignalLine sLine_hOb6nPiC;
  SignalLine sLine_GsLUvKtP;
  SignalLine sLine_ihhNVdUT;
  ControlVar cVar_GolTqN8Z;
  ControlBinop cBinop_3wzjlHnZ;
  ControlBinop cBinop_xPBshk3K;
  ControlBinop cBinop_1Ea8jtft;
  ControlBinop cBinop_J2pexcm8;
  ControlBinop cBinop_nUW4OzR1;
  ControlBinop cBinop_DFGY6rTp;
  ControlBinop cBinop_JxrsLTg7;
  ControlBinop cBinop_NLwMXtIe;
  ControlVar cVar_VeoMQZLm;
  ControlVar cVar_ZWPOyy8T;
  ControlVar cVar_1ud3xcc1;
  ControlVar cVar_6aw5Wh64;
  ControlVar cVar_WJNpXwDa;
  ControlBinop cBinop_PNRvgaFo;
  ControlVar cVar_JzgJO8lJ;
  ControlVar cVar_5qj7MFjF;
  ControlIf cIf_cHqnMh7L;
  ControlIf cIf_aD73Xtgl;
  ControlDelay cDelay_9O3RFjCQ;
  ControlBinop cBinop_2DonJL4F;
  ControlBinop cBinop_G4JSRepS;
  ControlIf cIf_ljHjhB5p;
  ControlIf cIf_MK394EZd;
  ControlDelay cDelay_WUe15rzP;
  ControlBinop cBinop_89BeoITJ;
  ControlBinop cBinop_X6fpzKzb;
  ControlIf cIf_usSogwuF;
  ControlIf cIf_5ZYiit4t;
  ControlDelay cDelay_VJHPczzR;
  ControlBinop cBinop_YlRCBhUT;
  ControlBinop cBinop_BHl7OvrU;
  ControlIf cIf_9lCE5FTH;
  ControlIf cIf_icDI9pIi;
  ControlDelay cDelay_LuC4oNvn;
  ControlBinop cBinop_Ykm90Vki;
  ControlBinop cBinop_Rlnsm7fw;
  ControlIf cIf_xfS1A1QO;
  ControlIf cIf_brsBQVlD;
  ControlDelay cDelay_6RdvY1AW;
  ControlBinop cBinop_dMwcjD1H;
  ControlBinop cBinop_PL0eWPY9;
  ControlIf cIf_vbAGjMbj;
  ControlIf cIf_ZR5fWeuF;
  ControlDelay cDelay_fdxuKjFn;
  ControlBinop cBinop_iYBl5r1t;
  ControlBinop cBinop_W33YeGsX;
  ControlIf cIf_tkMyN4bg;
  ControlIf cIf_aVzV4Ejw;
  ControlDelay cDelay_t8mmlHdT;
  ControlBinop cBinop_sIlEMpNw;
  ControlBinop cBinop_mcuWLXXX;
  ControlIf cIf_vVLUkwN5;
  ControlIf cIf_oqBBH3c2;
  ControlDelay cDelay_BbH9lfgX;
  ControlBinop cBinop_yWW5MAUR;
  ControlBinop cBinop_halTL7YE;
  ControlIf cIf_EYUmGTxq;
  ControlIf cIf_jYQ82juX;
  ControlDelay cDelay_mZ1ZfXFe;
  ControlBinop cBinop_wlICd6vW;
  ControlBinop cBinop_FIRrxugn;
  ControlIf cIf_QjDMD4k7;
  ControlIf cIf_0zdEGx5B;
  ControlDelay cDelay_bvjTMH23;
  ControlBinop cBinop_JYlIKYqk;
  ControlBinop cBinop_C6GcXIdF;
  ControlIf cIf_qqQVZm6M;
  ControlIf cIf_6QrISNTw;
  ControlDelay cDelay_5URasD5k;
  ControlBinop cBinop_5h35QAFa;
  ControlBinop cBinop_bhovpW3X;
  ControlIf cIf_ul9JqanZ;
  ControlIf cIf_weZE6TV7;
  ControlDelay cDelay_eYdBYwKs;
  ControlBinop cBinop_1z5aUl3o;
  ControlBinop cBinop_Eru9sGdD;
  SignalVarf sVarf_24Llj9VO;
  SignalVarf sVarf_qtXb8oVL;
  SignalVarf sVarf_IMKnWbkD;
  SignalVarf sVarf_xzu0OLAa;
  SignalVarf sVarf_s5h8TMfd;
  SignalVarf sVarf_EV7SjfUb;
  SignalVarf sVarf_9Fqm8JjX;
  SignalVarf sVarf_vVauwUYi;
  ControlVar cVar_B5VggnlA;
  ControlSlice cSlice_sVa4tm62;
  ControlVar cVar_K2SoT8XX;
  ControlSlice cSlice_LlTDdSVk;
  ControlVar cVar_5SCO2kUS;
  ControlSlice cSlice_1ovYnhkx;
  ControlVar cVar_yGq1DcEv;
  ControlSlice cSlice_vB6yra9H;
  ControlVar cVar_ftKj1so3;
  ControlSlice cSlice_unAPKUWV;
  ControlVar cVar_dMLtm9lc;
  ControlDelay cDelay_RifrG4Yw;
  ControlVar cVar_LUbmsTbo;
  ControlIf cIf_fY8z4I0C;
  ControlIf cIf_WHuH8Gib;
  ControlBinop cBinop_cYUuML26;
  ControlBinop cBinop_y4pYGs0S;
  ControlBinop cBinop_w2VpcfWQ;
  ControlBinop cBinop_1NgKv6VO;
  ControlBinop cBinop_uYZtDsmu;
  ControlSlice cSlice_xPOwjUYt;
  ControlVar cVar_XtGs1Kns;
  SignalVarf sVarf_8bDel6Uy;
  SignalVarf sVarf_wizyGo0R;
  SignalVarf sVarf_pIjcumhp;
  SignalVarf sVarf_bhGoFC8h;
  SignalVarf sVarf_L7ywj8Vh;
  SignalVarf sVarf_MUWmtkEP;
  ControlBinop cBinop_qmajW5lR;
  ControlBinop cBinop_0e6kYkzn;
  ControlVar cVar_IiwQtMmZ;
  ControlVar cVar_FMmZn9FI;
  ControlIf cIf_IGQyEmBp;
  ControlIf cIf_geSxqYMj;
  ControlDelay cDelay_3XEkPbXX;
  ControlBinop cBinop_UAaMJvrq;
  ControlBinop cBinop_6QLNRPfD;
  ControlIf cIf_XYnsPUsm;
  ControlIf cIf_Cgd9W5uF;
  ControlDelay cDelay_s8n0VvhL;
  ControlBinop cBinop_02rodNzI;
  ControlBinop cBinop_iIQfYD6J;
  ControlIf cIf_KxgyOh6x;
  ControlIf cIf_DWI3pe6Z;
  ControlDelay cDelay_PiUkLyXD;
  ControlBinop cBinop_JhvQiDkd;
  ControlBinop cBinop_wR1FTbS4;
  ControlIf cIf_lt101e7y;
  ControlIf cIf_fO2pj04m;
  ControlDelay cDelay_u1jXOVaH;
  ControlBinop cBinop_DjwffKBv;
  ControlBinop cBinop_swj0To6t;
  ControlIf cIf_s3QFvXaa;
  ControlIf cIf_gTsnpLLE;
  ControlDelay cDelay_8V3WilE2;
  ControlBinop cBinop_Ue9KezGQ;
  ControlBinop cBinop_eE6SxkRv;
  ControlIf cIf_fIpQUbM6;
  ControlIf cIf_KfNOQGYv;
  ControlDelay cDelay_HCxv6qYk;
  ControlBinop cBinop_yNXeg9xi;
  ControlBinop cBinop_ArAd3XTo;
  ControlIf cIf_CdeB4vAQ;
  ControlIf cIf_St0tPgOT;
  ControlDelay cDelay_du0IdDIb;
  ControlBinop cBinop_yrWPp6IR;
  ControlBinop cBinop_3JyAHPr0;
  ControlIf cIf_jDabV6J1;
  ControlIf cIf_jYwEwF9w;
  ControlDelay cDelay_fKDEPpe5;
  ControlBinop cBinop_w7xGtC3Z;
  ControlBinop cBinop_G8pDnSJt;
  ControlIf cIf_lpNk0EXO;
  ControlIf cIf_X7TfjCBT;
  ControlDelay cDelay_UvT6Vp3N;
  ControlBinop cBinop_Qt7X7kvc;
  ControlBinop cBinop_rW68GGZV;
  ControlIf cIf_u7KpzmAX;
  ControlIf cIf_LeOVcIHd;
  ControlDelay cDelay_miqvAJwj;
  ControlBinop cBinop_So1iOg2e;
  ControlBinop cBinop_N9Ogq9fM;
  ControlIf cIf_QGthaGGR;
  ControlIf cIf_Qz2KygHn;
  ControlDelay cDelay_7XlVqGA0;
  ControlBinop cBinop_V934B46d;
  ControlBinop cBinop_lmIJR8r3;
  ControlIf cIf_xcGe1OPF;
  ControlIf cIf_Rm01cPRO;
  ControlDelay cDelay_k8I9mE2U;
  ControlBinop cBinop_sUZSgngW;
  ControlBinop cBinop_pdkv8bvZ;
  SignalVarf sVarf_187MNlQd;
  SignalVarf sVarf_lbLnlqdn;
  SignalVarf sVarf_xSOLpGZO;
  SignalVarf sVarf_rjsjb4ky;
  SignalVarf sVarf_oiz24wGh;
  SignalVarf sVarf_rsZ5BTr4;
  SignalVarf sVarf_SftBaD2V;
  SignalVarf sVarf_21fk3Pa2;
  ControlVar cVar_CGkO0xNp;
  ControlSlice cSlice_jyYKCHSy;
  ControlVar cVar_hkPcOrg4;
  ControlSlice cSlice_LoClgciz;
  ControlVar cVar_KGMX23fe;
  ControlSlice cSlice_ioO9oTZS;
  ControlVar cVar_01gJucX2;
  ControlSlice cSlice_zMvcR9m3;
  ControlVar cVar_iIjy3gqg;
  ControlSlice cSlice_ufqj8Qpz;
  ControlVar cVar_HfWwDtXv;
  ControlDelay cDelay_dhPbYCzN;
  ControlVar cVar_MFyIg3Y5;
  ControlIf cIf_OvnJrEfx;
  ControlIf cIf_fDY0ueC6;
  ControlBinop cBinop_ThUc6uW2;
  ControlBinop cBinop_xAg77AyB;
  ControlBinop cBinop_tMSLJYDr;
  ControlBinop cBinop_2fbFj1D7;
  ControlBinop cBinop_y5jr7FOz;
  ControlSlice cSlice_8t3H2jBp;
  ControlVar cVar_hZ7w4ev4;
  SignalVarf sVarf_Xr3ZgG2k;
  SignalVarf sVarf_Sw6kXKE0;
  SignalVarf sVarf_1euyzL44;
  SignalVarf sVarf_UlqiaWMq;
  SignalVarf sVarf_OdDXnN1B;
  SignalVarf sVarf_qqjroiLe;
  ControlBinop cBinop_1LniQsex;
  ControlBinop cBinop_oFVyRbG0;
  ControlVar cVar_SDwT3eRx;
  SignalVarf sVarf_JvjTkjbX;
  SignalVarf sVarf_11VZpGbP;
  SignalVarf sVarf_1NQbXSqA;
  SignalVarf sVarf_lYIzsiUr;
  ControlBinop cBinop_V0GfCozM;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
