/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_7QdTuCyK);
  numBytes += sLine_init(&sLine_bfyAvs8n);
  numBytes += sLine_init(&sLine_GSNMmdQj);
  numBytes += sLine_init(&sLine_RCr9WmBH);
  numBytes += sLine_init(&sLine_XNVbNKcB);
  numBytes += sLine_init(&sLine_b2XXVnX6);
  numBytes += sLine_init(&sLine_QmVUPE3M);
  numBytes += sLine_init(&sLine_IZVBTRZZ);
  numBytes += sLine_init(&sLine_HcZn2YRe);
  numBytes += sLine_init(&sLine_C3fhADNu);
  numBytes += sLine_init(&sLine_aW2sooWe);
  numBytes += sLine_init(&sLine_GCpU2o8u);
  numBytes += sEnv_init(&sEnv_z5kG4mWN, 512, 256);
  numBytes += sEnv_init(&sEnv_dTpUJqTm, 512, 256);
  numBytes += sLine_init(&sLine_OrgfNzxO);
  numBytes += sLine_init(&sLine_a2NXECCt);
  numBytes += sLine_init(&sLine_PEdHdOhj);
  numBytes += sLine_init(&sLine_TDNXfMPO);
  numBytes += sLine_init(&sLine_AT31RMNa);
  numBytes += sLine_init(&sLine_ljgnVXoh);
  numBytes += sLine_init(&sLine_159VfxCB);
  numBytes += sLine_init(&sLine_twMeG4V8);
  numBytes += sLine_init(&sLine_fYgyUPwU);
  numBytes += sLine_init(&sLine_kiSijYRw);
  numBytes += sLine_init(&sLine_5PzvjFr5);
  numBytes += sLine_init(&sLine_thZ50IZE);
  numBytes += sLine_init(&sLine_0gg3fXD5);
  numBytes += sLine_init(&sLine_VTBoo2xA);
  numBytes += sLine_init(&sLine_8jE1x9u4);
  numBytes += sLine_init(&sLine_kakFBtiE);
  numBytes += sLine_init(&sLine_WjrvsioR);
  numBytes += sLine_init(&sLine_frDinQET);
  numBytes += sEnv_init(&sEnv_BPK2PezG, 512, 256);
  numBytes += sEnv_init(&sEnv_z0gYwpjd, 512, 256);
  numBytes += sLine_init(&sLine_QyJhiZr5);
  numBytes += sLine_init(&sLine_1jVGjqKD);
  numBytes += sLine_init(&sLine_mfusku04);
  numBytes += sLine_init(&sLine_jGWCXF4R);
  numBytes += sLine_init(&sLine_pqrGIDBx);
  numBytes += sLine_init(&sLine_hOb6nPiC);
  numBytes += sLine_init(&sLine_GsLUvKtP);
  numBytes += sLine_init(&sLine_ihhNVdUT);
  numBytes += cVar_init_f(&cVar_GolTqN8Z, 0.0f);
  numBytes += cVar_init_f(&cVar_VeoMQZLm, 0.0f);
  numBytes += cVar_init_f(&cVar_ZWPOyy8T, 0.0f);
  numBytes += cVar_init_f(&cVar_1ud3xcc1, 0.0f);
  numBytes += cVar_init_f(&cVar_6aw5Wh64, 0.0f);
  numBytes += cVar_init_f(&cVar_WJNpXwDa, 1.0f);
  numBytes += cVar_init_f(&cVar_JzgJO8lJ, 0.0f);
  numBytes += cVar_init_f(&cVar_5qj7MFjF, 0.0f);
  numBytes += cIf_init(&cIf_cHqnMh7L, false);
  numBytes += cIf_init(&cIf_aD73Xtgl, false);
  numBytes += cDelay_init(this, &cDelay_9O3RFjCQ, 10.0f);
  numBytes += cIf_init(&cIf_ljHjhB5p, false);
  numBytes += cIf_init(&cIf_MK394EZd, false);
  numBytes += cDelay_init(this, &cDelay_WUe15rzP, 10.0f);
  numBytes += cIf_init(&cIf_usSogwuF, false);
  numBytes += cIf_init(&cIf_5ZYiit4t, false);
  numBytes += cDelay_init(this, &cDelay_VJHPczzR, 10.0f);
  numBytes += cIf_init(&cIf_9lCE5FTH, false);
  numBytes += cIf_init(&cIf_icDI9pIi, false);
  numBytes += cDelay_init(this, &cDelay_LuC4oNvn, 10.0f);
  numBytes += cIf_init(&cIf_xfS1A1QO, false);
  numBytes += cIf_init(&cIf_brsBQVlD, false);
  numBytes += cDelay_init(this, &cDelay_6RdvY1AW, 10.0f);
  numBytes += cIf_init(&cIf_vbAGjMbj, false);
  numBytes += cIf_init(&cIf_ZR5fWeuF, false);
  numBytes += cDelay_init(this, &cDelay_fdxuKjFn, 10.0f);
  numBytes += cIf_init(&cIf_tkMyN4bg, false);
  numBytes += cIf_init(&cIf_aVzV4Ejw, false);
  numBytes += cDelay_init(this, &cDelay_t8mmlHdT, 10.0f);
  numBytes += cIf_init(&cIf_vVLUkwN5, false);
  numBytes += cIf_init(&cIf_oqBBH3c2, false);
  numBytes += cDelay_init(this, &cDelay_BbH9lfgX, 10.0f);
  numBytes += cIf_init(&cIf_EYUmGTxq, false);
  numBytes += cIf_init(&cIf_jYQ82juX, false);
  numBytes += cDelay_init(this, &cDelay_mZ1ZfXFe, 10.0f);
  numBytes += cIf_init(&cIf_QjDMD4k7, false);
  numBytes += cIf_init(&cIf_0zdEGx5B, false);
  numBytes += cDelay_init(this, &cDelay_bvjTMH23, 10.0f);
  numBytes += cIf_init(&cIf_qqQVZm6M, false);
  numBytes += cIf_init(&cIf_6QrISNTw, false);
  numBytes += cDelay_init(this, &cDelay_5URasD5k, 10.0f);
  numBytes += cIf_init(&cIf_ul9JqanZ, false);
  numBytes += cIf_init(&cIf_weZE6TV7, false);
  numBytes += cDelay_init(this, &cDelay_eYdBYwKs, 10.0f);
  numBytes += sVarf_init(&sVarf_24Llj9VO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qtXb8oVL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IMKnWbkD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xzu0OLAa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s5h8TMfd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EV7SjfUb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9Fqm8JjX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vVauwUYi, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_B5VggnlA, 0.0f);
  numBytes += cSlice_init(&cSlice_sVa4tm62, 1, -1);
  numBytes += cVar_init_f(&cVar_K2SoT8XX, 1.0f);
  numBytes += cSlice_init(&cSlice_LlTDdSVk, 1, -1);
  numBytes += cVar_init_f(&cVar_5SCO2kUS, 0.0f);
  numBytes += cSlice_init(&cSlice_1ovYnhkx, 1, -1);
  numBytes += cVar_init_f(&cVar_yGq1DcEv, 512.0f);
  numBytes += cSlice_init(&cSlice_vB6yra9H, 1, -1);
  numBytes += cVar_init_f(&cVar_ftKj1so3, 1.0f);
  numBytes += cSlice_init(&cSlice_unAPKUWV, 1, -1);
  numBytes += cVar_init_f(&cVar_dMLtm9lc, 1.0f);
  numBytes += cDelay_init(this, &cDelay_RifrG4Yw, 20.0f);
  numBytes += cVar_init_f(&cVar_LUbmsTbo, 0.0f);
  numBytes += cIf_init(&cIf_fY8z4I0C, false);
  numBytes += cIf_init(&cIf_WHuH8Gib, false);
  numBytes += cBinop_init(&cBinop_cYUuML26, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_xPOwjUYt, 1, -1);
  numBytes += cVar_init_f(&cVar_XtGs1Kns, 0.0f);
  numBytes += sVarf_init(&sVarf_8bDel6Uy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wizyGo0R, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pIjcumhp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bhGoFC8h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L7ywj8Vh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MUWmtkEP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IiwQtMmZ, 0.0f);
  numBytes += cVar_init_f(&cVar_FMmZn9FI, 0.0f);
  numBytes += cIf_init(&cIf_IGQyEmBp, false);
  numBytes += cIf_init(&cIf_geSxqYMj, false);
  numBytes += cDelay_init(this, &cDelay_3XEkPbXX, 10.0f);
  numBytes += cIf_init(&cIf_XYnsPUsm, false);
  numBytes += cIf_init(&cIf_Cgd9W5uF, false);
  numBytes += cDelay_init(this, &cDelay_s8n0VvhL, 10.0f);
  numBytes += cIf_init(&cIf_KxgyOh6x, false);
  numBytes += cIf_init(&cIf_DWI3pe6Z, false);
  numBytes += cDelay_init(this, &cDelay_PiUkLyXD, 10.0f);
  numBytes += cIf_init(&cIf_lt101e7y, false);
  numBytes += cIf_init(&cIf_fO2pj04m, false);
  numBytes += cDelay_init(this, &cDelay_u1jXOVaH, 10.0f);
  numBytes += cIf_init(&cIf_s3QFvXaa, false);
  numBytes += cIf_init(&cIf_gTsnpLLE, false);
  numBytes += cDelay_init(this, &cDelay_8V3WilE2, 10.0f);
  numBytes += cIf_init(&cIf_fIpQUbM6, false);
  numBytes += cIf_init(&cIf_KfNOQGYv, false);
  numBytes += cDelay_init(this, &cDelay_HCxv6qYk, 10.0f);
  numBytes += cIf_init(&cIf_CdeB4vAQ, false);
  numBytes += cIf_init(&cIf_St0tPgOT, false);
  numBytes += cDelay_init(this, &cDelay_du0IdDIb, 10.0f);
  numBytes += cIf_init(&cIf_jDabV6J1, false);
  numBytes += cIf_init(&cIf_jYwEwF9w, false);
  numBytes += cDelay_init(this, &cDelay_fKDEPpe5, 10.0f);
  numBytes += cIf_init(&cIf_lpNk0EXO, false);
  numBytes += cIf_init(&cIf_X7TfjCBT, false);
  numBytes += cDelay_init(this, &cDelay_UvT6Vp3N, 10.0f);
  numBytes += cIf_init(&cIf_u7KpzmAX, false);
  numBytes += cIf_init(&cIf_LeOVcIHd, false);
  numBytes += cDelay_init(this, &cDelay_miqvAJwj, 10.0f);
  numBytes += cIf_init(&cIf_QGthaGGR, false);
  numBytes += cIf_init(&cIf_Qz2KygHn, false);
  numBytes += cDelay_init(this, &cDelay_7XlVqGA0, 10.0f);
  numBytes += cIf_init(&cIf_xcGe1OPF, false);
  numBytes += cIf_init(&cIf_Rm01cPRO, false);
  numBytes += cDelay_init(this, &cDelay_k8I9mE2U, 10.0f);
  numBytes += sVarf_init(&sVarf_187MNlQd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lbLnlqdn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xSOLpGZO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rjsjb4ky, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oiz24wGh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rsZ5BTr4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SftBaD2V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_21fk3Pa2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_CGkO0xNp, 0.0f);
  numBytes += cSlice_init(&cSlice_jyYKCHSy, 1, -1);
  numBytes += cVar_init_f(&cVar_hkPcOrg4, 1.0f);
  numBytes += cSlice_init(&cSlice_LoClgciz, 1, -1);
  numBytes += cVar_init_f(&cVar_KGMX23fe, 0.0f);
  numBytes += cSlice_init(&cSlice_ioO9oTZS, 1, -1);
  numBytes += cVar_init_f(&cVar_01gJucX2, 512.0f);
  numBytes += cSlice_init(&cSlice_zMvcR9m3, 1, -1);
  numBytes += cVar_init_f(&cVar_iIjy3gqg, 1.0f);
  numBytes += cSlice_init(&cSlice_ufqj8Qpz, 1, -1);
  numBytes += cVar_init_f(&cVar_HfWwDtXv, 1.0f);
  numBytes += cDelay_init(this, &cDelay_dhPbYCzN, 20.0f);
  numBytes += cVar_init_f(&cVar_MFyIg3Y5, 0.0f);
  numBytes += cIf_init(&cIf_OvnJrEfx, false);
  numBytes += cIf_init(&cIf_fDY0ueC6, false);
  numBytes += cBinop_init(&cBinop_ThUc6uW2, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_8t3H2jBp, 1, -1);
  numBytes += cVar_init_f(&cVar_hZ7w4ev4, 0.0f);
  numBytes += sVarf_init(&sVarf_Xr3ZgG2k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Sw6kXKE0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1euyzL44, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UlqiaWMq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OdDXnN1B, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qqjroiLe, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_SDwT3eRx, 0.0f);
  numBytes += sVarf_init(&sVarf_JvjTkjbX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_11VZpGbP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1NQbXSqA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lYIzsiUr, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_z5kG4mWN);
  sEnv_free(&sEnv_dTpUJqTm);
  sEnv_free(&sEnv_BPK2PezG);
  sEnv_free(&sEnv_z0gYwpjd);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cKqUtYj1_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8CpNk7UX_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GD6UG4eU_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BrvpHost_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yrVjI7fG_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gFAdNmvg_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4e9ueaY9_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tT90hpQG_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dVhEr0PJ_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gVOclxZC_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MX434jCG_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FVPm3o9V_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mkIKJYlH_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6K15Xr9b_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CU38V6wk_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5s6yALMP_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uc0TFB7o_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uSSMXVnG_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Nf2Idi3n_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yq0obu3O_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t3ElHYV1_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_GolTqN8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IUSvkOm1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_3wzjlHnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xPBshk3K_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xPBshk3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_1Ea8jtft_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1Ea8jtft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_J2pexcm8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_J2pexcm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LcJkYQU5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jiswgFzX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LcJkYQU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nUW4OzR1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jiswgFzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cryBKJKU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_nUW4OzR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JxrsLTg7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cryBKJKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DFGY6rTp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DFGY6rTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NLwMXtIe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JxrsLTg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XdQ2cTRj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_NLwMXtIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ij1HUBJk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_VeoMQZLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2ixHdDko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_ZWPOyy8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wdI0RgtX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_1ud3xcc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xvvdKEtr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_6aw5Wh64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vK4R15ID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_WJNpXwDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PNRvgaFo_sendMessage);
  cMsg_hEj92E5y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_PNRvgaFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WJNpXwDa, 1, m, &cVar_WJNpXwDa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_u8WMy3kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yyDEfytq_sendMessage(_c, 0, m);
  cMsg_OwZEYBxc_sendMessage(_c, 0, m);
  cMsg_FjXmTUBm_sendMessage(_c, 0, m);
  cMsg_y0z4O6zX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_JzgJO8lJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C4juarrG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_5qj7MFjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_svDL8a9K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_u1586xG0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1apiTbgz_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NB8pwKxp_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bCWDqjco_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8KrZF3Uh_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uRUSMeUO_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JVCbRCEl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_1apiTbgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tfutJNfU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_NB8pwKxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mp6bDJxr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_bCWDqjco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jDhU8Z7D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_8KrZF3Uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qBuZEXM3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_uRUSMeUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_40rjpPRe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_JVCbRCEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8smaO9ZR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_cHqnMh7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GHE7t0yx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_aD73Xtgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oK46jnhI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_7QpXL5GD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YOnCEP0n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YOnCEP0n_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9O3RFjCQ, 1, m, &cDelay_9O3RFjCQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ZwpLA1W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_9O3RFjCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9O3RFjCQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cHqnMh7L, 0, m, &cIf_cHqnMh7L_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YOnCEP0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9O3RFjCQ, 0, m, &cDelay_9O3RFjCQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0ZwpLA1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9O3RFjCQ, 0, m, &cDelay_9O3RFjCQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2DonJL4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RxSmSPVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ir78NOwj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_G4JSRepS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W7vfgkya_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OddebPCp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_W7vfgkya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cHqnMh7L, 1, m, &cIf_cHqnMh7L_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OddebPCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7QpXL5GD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Ir78NOwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aD73Xtgl, 0, m, &cIf_aD73Xtgl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RxSmSPVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aD73Xtgl, 1, m, &cIf_aD73Xtgl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oK46jnhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RCr9WmBH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_GHE7t0yx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RCr9WmBH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ljHjhB5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zLiDg7OH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_MK394EZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tJsaHfP6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_0un4s8pw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2QrXNj0Q_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2QrXNj0Q_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WUe15rzP, 1, m, &cDelay_WUe15rzP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Xk9701w_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_WUe15rzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WUe15rzP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ljHjhB5p, 0, m, &cIf_ljHjhB5p_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2QrXNj0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WUe15rzP, 0, m, &cDelay_WUe15rzP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5Xk9701w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WUe15rzP, 0, m, &cDelay_WUe15rzP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_89BeoITJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lo5Y2SPv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UcqBdWJD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_X6fpzKzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7fN8WSHY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TwjxiO6E_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TwjxiO6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0un4s8pw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_7fN8WSHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ljHjhB5p, 1, m, &cIf_ljHjhB5p_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UcqBdWJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MK394EZd, 0, m, &cIf_MK394EZd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Lo5Y2SPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MK394EZd, 1, m, &cIf_MK394EZd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tJsaHfP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QmVUPE3M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_zLiDg7OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QmVUPE3M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_usSogwuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oQjLOQeo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_5ZYiit4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fniRX0FQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_8TXlW3Rj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YdRRCc8Q_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YdRRCc8Q_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VJHPczzR, 1, m, &cDelay_VJHPczzR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EusvZEWN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_VJHPczzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VJHPczzR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_usSogwuF, 0, m, &cIf_usSogwuF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YdRRCc8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJHPczzR, 0, m, &cDelay_VJHPczzR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EusvZEWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJHPczzR, 0, m, &cDelay_VJHPczzR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YlRCBhUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GmtUDWY5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yGx6C8dj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BHl7OvrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5qvBLdQu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GbD0YsLm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5qvBLdQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_usSogwuF, 1, m, &cIf_usSogwuF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GbD0YsLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8TXlW3Rj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_yGx6C8dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5ZYiit4t, 0, m, &cIf_5ZYiit4t_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GmtUDWY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5ZYiit4t, 1, m, &cIf_5ZYiit4t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fniRX0FQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C3fhADNu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_oQjLOQeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C3fhADNu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_9lCE5FTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7F54PR4J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_icDI9pIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iMZwxm5K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5BHdAb2n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GmrexnlS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GmrexnlS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LuC4oNvn, 1, m, &cDelay_LuC4oNvn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASZUoazc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_LuC4oNvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LuC4oNvn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9lCE5FTH, 0, m, &cIf_9lCE5FTH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GmrexnlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LuC4oNvn, 0, m, &cDelay_LuC4oNvn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ASZUoazc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LuC4oNvn, 0, m, &cDelay_LuC4oNvn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ykm90Vki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SjGmO9CT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zfUDGKbt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Rlnsm7fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z5sjwbT1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PbxUtEPS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z5sjwbT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9lCE5FTH, 1, m, &cIf_9lCE5FTH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PbxUtEPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5BHdAb2n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zfUDGKbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_icDI9pIi, 0, m, &cIf_icDI9pIi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SjGmO9CT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_icDI9pIi, 1, m, &cIf_icDI9pIi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_iMZwxm5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XNVbNKcB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7F54PR4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XNVbNKcB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xfS1A1QO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xzcx7w7m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_brsBQVlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3CXNIKcZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_W8OaEA9i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ynNeb7tL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ynNeb7tL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6RdvY1AW, 1, m, &cDelay_6RdvY1AW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wExabmXi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_6RdvY1AW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6RdvY1AW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xfS1A1QO, 0, m, &cIf_xfS1A1QO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ynNeb7tL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6RdvY1AW, 0, m, &cDelay_6RdvY1AW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wExabmXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6RdvY1AW, 0, m, &cDelay_6RdvY1AW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dMwcjD1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z94mV37Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yv1xVgq4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PL0eWPY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rlSuvwAH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5auCCmDl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5auCCmDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_W8OaEA9i_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_rlSuvwAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xfS1A1QO, 1, m, &cIf_xfS1A1QO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Yv1xVgq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_brsBQVlD, 0, m, &cIf_brsBQVlD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z94mV37Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_brsBQVlD, 1, m, &cIf_brsBQVlD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3CXNIKcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IZVBTRZZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xzcx7w7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IZVBTRZZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vbAGjMbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AqWXdEVI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ZR5fWeuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vfmeuNQf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_z2tETFvo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2zTC9ezs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2zTC9ezs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fdxuKjFn, 1, m, &cDelay_fdxuKjFn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6k8jJsV3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_fdxuKjFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fdxuKjFn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vbAGjMbj, 0, m, &cIf_vbAGjMbj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2zTC9ezs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fdxuKjFn, 0, m, &cDelay_fdxuKjFn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6k8jJsV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fdxuKjFn, 0, m, &cDelay_fdxuKjFn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iYBl5r1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3pwZvrzb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wn0Tnnzv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_W33YeGsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EbZas6cg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WkuCAdod_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WkuCAdod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_z2tETFvo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_EbZas6cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbAGjMbj, 1, m, &cIf_vbAGjMbj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wn0Tnnzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZR5fWeuF, 0, m, &cIf_ZR5fWeuF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3pwZvrzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZR5fWeuF, 1, m, &cIf_ZR5fWeuF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vfmeuNQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aW2sooWe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AqWXdEVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aW2sooWe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_tkMyN4bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_a9C6aHL3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_aVzV4Ejw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DTFmLSdW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_1yzDLZsu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FBU1B8hB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FBU1B8hB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_t8mmlHdT, 1, m, &cDelay_t8mmlHdT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nftg7njj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_t8mmlHdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_t8mmlHdT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tkMyN4bg, 0, m, &cIf_tkMyN4bg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FBU1B8hB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_t8mmlHdT, 0, m, &cDelay_t8mmlHdT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nftg7njj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_t8mmlHdT, 0, m, &cDelay_t8mmlHdT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sIlEMpNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MKmKK2Bl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vsDDxrbe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mcuWLXXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AKkOg8dz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bNY9TZ0i_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bNY9TZ0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1yzDLZsu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AKkOg8dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tkMyN4bg, 1, m, &cIf_tkMyN4bg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vsDDxrbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aVzV4Ejw, 0, m, &cIf_aVzV4Ejw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MKmKK2Bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aVzV4Ejw, 1, m, &cIf_aVzV4Ejw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DTFmLSdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b2XXVnX6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_a9C6aHL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b2XXVnX6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vVLUkwN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zRzm4PnN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_oqBBH3c2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4ZPGCOmi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3CoPfw2X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LmEJ9qeo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LmEJ9qeo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BbH9lfgX, 1, m, &cDelay_BbH9lfgX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JQLJ7JL9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_BbH9lfgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BbH9lfgX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vVLUkwN5, 0, m, &cIf_vVLUkwN5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LmEJ9qeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BbH9lfgX, 0, m, &cDelay_BbH9lfgX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JQLJ7JL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BbH9lfgX, 0, m, &cDelay_BbH9lfgX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yWW5MAUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pPX4MRSD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xkyKiZln_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_halTL7YE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jE1EY0De_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lw1lbMTl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lw1lbMTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3CoPfw2X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_jE1EY0De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vVLUkwN5, 1, m, &cIf_vVLUkwN5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xkyKiZln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oqBBH3c2, 0, m, &cIf_oqBBH3c2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pPX4MRSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oqBBH3c2, 1, m, &cIf_oqBBH3c2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4ZPGCOmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HcZn2YRe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_zRzm4PnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HcZn2YRe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_EYUmGTxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nb7MhTtA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jYQ82juX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F88PbBx0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_NAqTQASI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_b8eW82h5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_b8eW82h5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mZ1ZfXFe, 1, m, &cDelay_mZ1ZfXFe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hTbKsiL1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_mZ1ZfXFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mZ1ZfXFe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EYUmGTxq, 0, m, &cIf_EYUmGTxq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_b8eW82h5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mZ1ZfXFe, 0, m, &cDelay_mZ1ZfXFe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hTbKsiL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mZ1ZfXFe, 0, m, &cDelay_mZ1ZfXFe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wlICd6vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MnDPQBzz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBKZq96Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FIRrxugn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NwJ6d78m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T2BbT8fX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NwJ6d78m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EYUmGTxq, 1, m, &cIf_EYUmGTxq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T2BbT8fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NAqTQASI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ZBKZq96Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jYQ82juX, 0, m, &cIf_jYQ82juX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MnDPQBzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jYQ82juX, 1, m, &cIf_jYQ82juX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_F88PbBx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GCpU2o8u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nb7MhTtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GCpU2o8u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_QjDMD4k7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W9Rhh5H9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_0zdEGx5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_x99vWHtV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_6IZl2bUK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hPZl1Ajc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hPZl1Ajc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bvjTMH23, 1, m, &cDelay_bvjTMH23_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YpJLpQHZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_bvjTMH23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bvjTMH23, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QjDMD4k7, 0, m, &cIf_QjDMD4k7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hPZl1Ajc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bvjTMH23, 0, m, &cDelay_bvjTMH23_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YpJLpQHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bvjTMH23, 0, m, &cDelay_bvjTMH23_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JYlIKYqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yf0Wal59_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SaM2wHag_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_C6GcXIdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i8NBcdi4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0azaCDMM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0azaCDMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6IZl2bUK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_i8NBcdi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QjDMD4k7, 1, m, &cIf_QjDMD4k7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SaM2wHag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0zdEGx5B, 0, m, &cIf_0zdEGx5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Yf0Wal59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0zdEGx5B, 1, m, &cIf_0zdEGx5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x99vWHtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7QdTuCyK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_W9Rhh5H9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7QdTuCyK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_qqQVZm6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KTapLssu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_6QrISNTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YsA5Gjhh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_01gUArrW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_D5FOq16x_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_D5FOq16x_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5URasD5k, 1, m, &cDelay_5URasD5k_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kru5AXhE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_5URasD5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5URasD5k, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qqQVZm6M, 0, m, &cIf_qqQVZm6M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_D5FOq16x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5URasD5k, 0, m, &cDelay_5URasD5k_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kru5AXhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5URasD5k, 0, m, &cDelay_5URasD5k_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5h35QAFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pH80Rk50_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZsarVCpN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_bhovpW3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uuM12vaG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8oITiUEI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uuM12vaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qqQVZm6M, 1, m, &cIf_qqQVZm6M_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8oITiUEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_01gUArrW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ZsarVCpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6QrISNTw, 0, m, &cIf_6QrISNTw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pH80Rk50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6QrISNTw, 1, m, &cIf_6QrISNTw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YsA5Gjhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bfyAvs8n, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KTapLssu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bfyAvs8n, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ul9JqanZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ILRp84J1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_weZE6TV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MSi0z9Cx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_TmNvSBFQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sACsfBHc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sACsfBHc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eYdBYwKs, 1, m, &cDelay_eYdBYwKs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9zg3m8Od_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_eYdBYwKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eYdBYwKs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ul9JqanZ, 0, m, &cIf_ul9JqanZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sACsfBHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eYdBYwKs, 0, m, &cDelay_eYdBYwKs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9zg3m8Od_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eYdBYwKs, 0, m, &cDelay_eYdBYwKs_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1z5aUl3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1i0xgwx5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sf173qzG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Eru9sGdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BZ4PfYS5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2G3RUEgs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2G3RUEgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TmNvSBFQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_BZ4PfYS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ul9JqanZ, 1, m, &cIf_ul9JqanZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sf173qzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_weZE6TV7, 0, m, &cIf_weZE6TV7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1i0xgwx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_weZE6TV7, 1, m, &cIf_weZE6TV7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MSi0z9Cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GSNMmdQj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ILRp84J1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GSNMmdQj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_tfutJNfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_YZsFIq5B_sendMessage(_c, 0, m);
  cMsg_Fyd7QV0Y_sendMessage(_c, 0, m);
  cMsg_lVt1zAow_sendMessage(_c, 0, m);
  cMsg_XMx6dFCw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_mp6bDJxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_YZsFIq5B_sendMessage(_c, 0, m);
  cMsg_lJDamGUA_sendMessage(_c, 0, m);
  cMsg_gJKxILkv_sendMessage(_c, 0, m);
  cMsg_XFPK8k5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jDhU8Z7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_kL0ixBu5_sendMessage(_c, 0, m);
  cMsg_lJDamGUA_sendMessage(_c, 0, m);
  cMsg_XMx6dFCw_sendMessage(_c, 0, m);
  cMsg_VqOGhWN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qBuZEXM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_kL0ixBu5_sendMessage(_c, 0, m);
  cMsg_cGSYnDmQ_sendMessage(_c, 0, m);
  cMsg_lVt1zAow_sendMessage(_c, 0, m);
  cMsg_kDCBwMtq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_40rjpPRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_TBnfcYk8_sendMessage(_c, 0, m);
  cMsg_XFPK8k5a_sendMessage(_c, 0, m);
  cMsg_Py9itYaZ_sendMessage(_c, 0, m);
  cMsg_lVt1zAow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8smaO9ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_TBnfcYk8_sendMessage(_c, 0, m);
  cMsg_kDCBwMtq_sendMessage(_c, 0, m);
  cMsg_lJDamGUA_sendMessage(_c, 0, m);
  cMsg_oTo3SWOv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_evBR6Xrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G4JSRepS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2DonJL4F_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZWhGMsCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G4JSRepS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2DonJL4F_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rsu5eGGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X6fpzKzb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_89BeoITJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cNaC56my_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X6fpzKzb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_89BeoITJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wc0Vv7Bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BHl7OvrU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YlRCBhUT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3NyHH7Sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BHl7OvrU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YlRCBhUT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YZsFIq5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_evBR6Xrw_sendMessage(_c, 0, m);
  cMsg_cNaC56my_sendMessage(_c, 0, m);
  cMsg_3NyHH7Sl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kL0ixBu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ZWhGMsCK_sendMessage(_c, 0, m);
  cMsg_rsu5eGGC_sendMessage(_c, 0, m);
  cMsg_3NyHH7Sl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TBnfcYk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ZWhGMsCK_sendMessage(_c, 0, m);
  cMsg_cNaC56my_sendMessage(_c, 0, m);
  cMsg_wc0Vv7Bb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_JnAZb9Wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Rlnsm7fw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ykm90Vki_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kSHcaQuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Rlnsm7fw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ykm90Vki_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hNBY6TDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PL0eWPY9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dMwcjD1H_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xzBKIjCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PL0eWPY9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dMwcjD1H_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_V0BhAQpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W33YeGsX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iYBl5r1t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_agMzAP8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W33YeGsX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iYBl5r1t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lJDamGUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_kSHcaQuK_sendMessage(_c, 0, m);
  cMsg_xzBKIjCT_sendMessage(_c, 0, m);
  cMsg_agMzAP8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Fyd7QV0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_kSHcaQuK_sendMessage(_c, 0, m);
  cMsg_hNBY6TDa_sendMessage(_c, 0, m);
  cMsg_V0BhAQpu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cGSYnDmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_JnAZb9Wo_sendMessage(_c, 0, m);
  cMsg_xzBKIjCT_sendMessage(_c, 0, m);
  cMsg_V0BhAQpu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5oFVpgAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C6GcXIdF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JYlIKYqk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_e2IMPjG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C6GcXIdF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JYlIKYqk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_s915bon3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bhovpW3X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5h35QAFa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JQ3TgHdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bhovpW3X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5h35QAFa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dflxXvDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Eru9sGdD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1z5aUl3o_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_czWJrvSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Eru9sGdD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1z5aUl3o_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kDCBwMtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_5oFVpgAw_sendMessage(_c, 0, m);
  cMsg_JQ3TgHdV_sendMessage(_c, 0, m);
  cMsg_czWJrvSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XFPK8k5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_e2IMPjG7_sendMessage(_c, 0, m);
  cMsg_s915bon3_sendMessage(_c, 0, m);
  cMsg_czWJrvSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XMx6dFCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_e2IMPjG7_sendMessage(_c, 0, m);
  cMsg_JQ3TgHdV_sendMessage(_c, 0, m);
  cMsg_dflxXvDa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_wAahy0HA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mcuWLXXX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sIlEMpNw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lK4aJWKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mcuWLXXX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sIlEMpNw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AIEQDun7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_halTL7YE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yWW5MAUR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_moDAbnBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_halTL7YE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yWW5MAUR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FGwuOquo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FIRrxugn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wlICd6vW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ASDPeSVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FIRrxugn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wlICd6vW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lVt1zAow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_lK4aJWKU_sendMessage(_c, 0, m);
  cMsg_moDAbnBa_sendMessage(_c, 0, m);
  cMsg_ASDPeSVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gJKxILkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_lK4aJWKU_sendMessage(_c, 0, m);
  cMsg_AIEQDun7_sendMessage(_c, 0, m);
  cMsg_FGwuOquo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oTo3SWOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_wAahy0HA_sendMessage(_c, 0, m);
  cMsg_AIEQDun7_sendMessage(_c, 0, m);
  cMsg_ASDPeSVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Py9itYaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_JnAZb9Wo_sendMessage(_c, 0, m);
  cMsg_hNBY6TDa_sendMessage(_c, 0, m);
  cMsg_agMzAP8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_VqOGhWN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_wAahy0HA_sendMessage(_c, 0, m);
  cMsg_moDAbnBa_sendMessage(_c, 0, m);
  cMsg_FGwuOquo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_B5VggnlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6mSlu1pL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_X1K4FmD0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sVa4tm62, 0, m, &cSlice_sVa4tm62_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0ZYeIsC5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_sVa4tm62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EOFnaJJC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EOFnaJJC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_K2SoT8XX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EOFnaJJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_EOFnaJJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gVOclxZC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_QaT0GdsJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LlTDdSVk, 0, m, &cSlice_LlTDdSVk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_10ZPC4Br_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_LlTDdSVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6afOwbEP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6afOwbEP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_5SCO2kUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6afOwbEP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_6afOwbEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6K15Xr9b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_10ZPC4Br_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1ovYnhkx, 0, m, &cSlice_1ovYnhkx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_X1K4FmD0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_1ovYnhkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YTkBzE4f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YTkBzE4f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_yGq1DcEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YTkBzE4f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_YTkBzE4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dVhEr0PJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_0ZYeIsC5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vB6yra9H, 0, m, &cSlice_vB6yra9H_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Jc2cxcwz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_vB6yra9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jRADr5Wv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jRADr5Wv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_ftKj1so3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jRADr5Wv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_jRADr5Wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mkIKJYlH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Jc2cxcwz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_unAPKUWV, 0, m, &cSlice_unAPKUWV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YW8V4Sk3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_unAPKUWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t0ixtZqx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t0ixtZqx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_dMLtm9lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t0ixtZqx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_t0ixtZqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FVPm3o9V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_qdwphRQg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HRyUYze1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HRyUYze1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RifrG4Yw, 1, m, &cDelay_RifrG4Yw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fxevt2lg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_RifrG4Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RifrG4Yw, m);
  cMsg_g81xz6ci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HRyUYze1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RifrG4Yw, 0, m, &cDelay_RifrG4Yw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fxevt2lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RifrG4Yw, 0, m, &cDelay_RifrG4Yw_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_LUbmsTbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cYUuML26, HV_BINOP_SUBTRACT, 0, m, &cBinop_cYUuML26_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_fY8z4I0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jcTiqM4x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_WHuH8Gib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jcTiqM4x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_z5kG4mWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LUbmsTbo, 0, m, &cVar_LUbmsTbo_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_dTpUJqTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wWoCetCZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hEeVqeyL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cdZCjlZ2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cYUuML26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kykY7jMd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kykY7jMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_y4pYGs0S_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_y4pYGs0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_uYZtDsmu_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_w2VpcfWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FAOrEDtY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qx2WnN2P_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Qx2WnN2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p7BzDptS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_FAOrEDtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fY8z4I0C, 1, m, &cIf_fY8z4I0C_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1NgKv6VO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WHuH8Gib, 1, m, &cIf_WHuH8Gib_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_p7BzDptS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_fY8z4I0C, 0, m, &cIf_fY8z4I0C_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uYZtDsmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WHuH8Gib, 0, m, &cIf_WHuH8Gib_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cdZCjlZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LUbmsTbo, 0, m, &cVar_LUbmsTbo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hEeVqeyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cYUuML26, HV_BINOP_SUBTRACT, 1, m, &cBinop_cYUuML26_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wWoCetCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cMsg_jcTiqM4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OrgfNzxO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_YW8V4Sk3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xPOwjUYt, 0, m, &cSlice_xPOwjUYt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_xPOwjUYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CCzsHmJc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CCzsHmJc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_XtGs1Kns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CCzsHmJc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_CCzsHmJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MX434jCG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_C4juarrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ljgnVXoh, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_svDL8a9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TDNXfMPO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_qmajW5lR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5qj7MFjF, 0, m, &cVar_5qj7MFjF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6mSlu1pL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AT31RMNa, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YoJeJPyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rI6XtsFW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_LGrcIoHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qdwphRQg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_g81xz6ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a2NXECCt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rI6XtsFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a2NXECCt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Um28SwZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_0e6kYkzn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0e6kYkzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zw0qsyGY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Zw0qsyGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PEdHdOhj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_IiwQtMmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_muuklgMk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_FMmZn9FI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s0w7L1Oz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_YR8Sgf1w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J7K3eYHl_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B4Tmy79o_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mpvYSj1n_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nblxbgh0_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LDkVUh2g_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7mSQqvbv_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_J7K3eYHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RGDppBTY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_B4Tmy79o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zWD1zpIC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_mpvYSj1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aO55ixTy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_nblxbgh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qWfsJph_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_LDkVUh2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BfNDc4Ii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_7mSQqvbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qaiVRXZt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_IGQyEmBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1CfBqnPG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_geSxqYMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hriBAIXo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_osimkXqY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sZwt6R0C_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sZwt6R0C_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3XEkPbXX, 1, m, &cDelay_3XEkPbXX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CldvHgnF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_3XEkPbXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3XEkPbXX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IGQyEmBp, 0, m, &cIf_IGQyEmBp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sZwt6R0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3XEkPbXX, 0, m, &cDelay_3XEkPbXX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CldvHgnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3XEkPbXX, 0, m, &cDelay_3XEkPbXX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UAaMJvrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zByTKCns_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDjg2Pf2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6QLNRPfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_633QbyLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HEsqPnVa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HEsqPnVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_osimkXqY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_633QbyLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IGQyEmBp, 1, m, &cIf_IGQyEmBp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zByTKCns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_geSxqYMj, 1, m, &cIf_geSxqYMj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CDjg2Pf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_geSxqYMj, 0, m, &cIf_geSxqYMj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hriBAIXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kiSijYRw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_1CfBqnPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kiSijYRw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_XYnsPUsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wbwwPGZm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Cgd9W5uF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gceamlip_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_EzFnwV2r_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KETmwvAe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KETmwvAe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_s8n0VvhL, 1, m, &cDelay_s8n0VvhL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U8OCyoY8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_s8n0VvhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_s8n0VvhL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XYnsPUsm, 0, m, &cIf_XYnsPUsm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KETmwvAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_s8n0VvhL, 0, m, &cDelay_s8n0VvhL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_U8OCyoY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_s8n0VvhL, 0, m, &cDelay_s8n0VvhL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_02rodNzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ysZhSnMI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r2s0gmsM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iIQfYD6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hn6xJOmW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cK37IPci_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cK37IPci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EzFnwV2r_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hn6xJOmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XYnsPUsm, 1, m, &cIf_XYnsPUsm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_r2s0gmsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cgd9W5uF, 0, m, &cIf_Cgd9W5uF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ysZhSnMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cgd9W5uF, 1, m, &cIf_Cgd9W5uF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gceamlip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0gg3fXD5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wbwwPGZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0gg3fXD5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_KxgyOh6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KoUZ2Xhw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DWI3pe6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2trtA1Lt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_GTP68znY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ouA8YrQ6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ouA8YrQ6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PiUkLyXD, 1, m, &cDelay_PiUkLyXD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g3W3fsYs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_PiUkLyXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PiUkLyXD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KxgyOh6x, 0, m, &cIf_KxgyOh6x_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ouA8YrQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PiUkLyXD, 0, m, &cDelay_PiUkLyXD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_g3W3fsYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PiUkLyXD, 0, m, &cDelay_PiUkLyXD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JhvQiDkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fyk3Yuib_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GJFopR5I_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wR1FTbS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x2YPvfcT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ks09Dhgs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ks09Dhgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GTP68znY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_x2YPvfcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KxgyOh6x, 1, m, &cIf_KxgyOh6x_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GJFopR5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DWI3pe6Z, 0, m, &cIf_DWI3pe6Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Fyk3Yuib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DWI3pe6Z, 1, m, &cIf_DWI3pe6Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2trtA1Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kakFBtiE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KoUZ2Xhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kakFBtiE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_lt101e7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0yW2buwI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_fO2pj04m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SSgn1kFK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ZddO5hZV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aPD9tvt2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aPD9tvt2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_u1jXOVaH, 1, m, &cDelay_u1jXOVaH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lqAhInOl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_u1jXOVaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u1jXOVaH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lt101e7y, 0, m, &cIf_lt101e7y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aPD9tvt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_u1jXOVaH, 0, m, &cDelay_u1jXOVaH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lqAhInOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_u1jXOVaH, 0, m, &cDelay_u1jXOVaH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DjwffKBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_04jHeTQb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qrip1jLm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_swj0To6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_exyPZfh4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ad89OrYr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_exyPZfh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lt101e7y, 1, m, &cIf_lt101e7y_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ad89OrYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZddO5hZV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_04jHeTQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fO2pj04m, 1, m, &cIf_fO2pj04m_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Qrip1jLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fO2pj04m, 0, m, &cIf_fO2pj04m_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SSgn1kFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5PzvjFr5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0yW2buwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5PzvjFr5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_s3QFvXaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HkK9eut5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_gTsnpLLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_P7ba8Fx0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_lRBbbxnA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uvsY8tuX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uvsY8tuX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8V3WilE2, 1, m, &cDelay_8V3WilE2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GTMXv85w_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8V3WilE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8V3WilE2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_s3QFvXaa, 0, m, &cIf_s3QFvXaa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uvsY8tuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8V3WilE2, 0, m, &cDelay_8V3WilE2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GTMXv85w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8V3WilE2, 0, m, &cDelay_8V3WilE2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ue9KezGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RMYJO6Pf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UDK140jZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eE6SxkRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hlV1deJA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OL78md1C_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OL78md1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lRBbbxnA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hlV1deJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s3QFvXaa, 1, m, &cIf_s3QFvXaa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RMYJO6Pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gTsnpLLE, 1, m, &cIf_gTsnpLLE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UDK140jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gTsnpLLE, 0, m, &cIf_gTsnpLLE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P7ba8Fx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VTBoo2xA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HkK9eut5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VTBoo2xA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_fIpQUbM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rhWoVTAq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_KfNOQGYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jyFsGj1Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_wAVGp6Xi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FFSaPw5w_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FFSaPw5w_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HCxv6qYk, 1, m, &cDelay_HCxv6qYk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GPqhsCFP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_HCxv6qYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HCxv6qYk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fIpQUbM6, 0, m, &cIf_fIpQUbM6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FFSaPw5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HCxv6qYk, 0, m, &cDelay_HCxv6qYk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GPqhsCFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HCxv6qYk, 0, m, &cDelay_HCxv6qYk_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yNXeg9xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kGYP4wLf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TssAZcGH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ArAd3XTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N1D1i75J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9tAUieF0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9tAUieF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wAVGp6Xi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_N1D1i75J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fIpQUbM6, 1, m, &cIf_fIpQUbM6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TssAZcGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KfNOQGYv, 0, m, &cIf_KfNOQGYv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kGYP4wLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KfNOQGYv, 1, m, &cIf_KfNOQGYv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jyFsGj1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WjrvsioR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rhWoVTAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WjrvsioR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_CdeB4vAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rLIlYtqR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_St0tPgOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_geIZFF99_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_oqIdPVly_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_efomWyhT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_efomWyhT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_du0IdDIb, 1, m, &cDelay_du0IdDIb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XRUIw2L4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_du0IdDIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_du0IdDIb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CdeB4vAQ, 0, m, &cIf_CdeB4vAQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_efomWyhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_du0IdDIb, 0, m, &cDelay_du0IdDIb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XRUIw2L4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_du0IdDIb, 0, m, &cDelay_du0IdDIb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yrWPp6IR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FTp3HI7W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nDZCOF3G_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3JyAHPr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4WuUeTbl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UOhB5KOV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UOhB5KOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oqIdPVly_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_4WuUeTbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CdeB4vAQ, 1, m, &cIf_CdeB4vAQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nDZCOF3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_St0tPgOT, 0, m, &cIf_St0tPgOT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FTp3HI7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_St0tPgOT, 1, m, &cIf_St0tPgOT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_geIZFF99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_thZ50IZE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rLIlYtqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_thZ50IZE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_jDabV6J1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2g06Y689_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jYwEwF9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_h1Mr2uGp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_KmEhJ3BE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uMjypQh5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uMjypQh5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fKDEPpe5, 1, m, &cDelay_fKDEPpe5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tVU3Bg5V_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_fKDEPpe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fKDEPpe5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jDabV6J1, 0, m, &cIf_jDabV6J1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uMjypQh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fKDEPpe5, 0, m, &cDelay_fKDEPpe5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tVU3Bg5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fKDEPpe5, 0, m, &cDelay_fKDEPpe5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_w7xGtC3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SIn0FT1x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v73CO2Hj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_G8pDnSJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8vL1JMEV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_axxTUe5h_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_axxTUe5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KmEhJ3BE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_8vL1JMEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jDabV6J1, 1, m, &cIf_jDabV6J1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_v73CO2Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jYwEwF9w, 0, m, &cIf_jYwEwF9w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SIn0FT1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jYwEwF9w, 1, m, &cIf_jYwEwF9w_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_h1Mr2uGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8jE1x9u4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2g06Y689_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8jE1x9u4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_lpNk0EXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5LplzYxc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_X7TfjCBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PRwRKej8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_1SckbTFi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PaKHIdOG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PaKHIdOG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UvT6Vp3N, 1, m, &cDelay_UvT6Vp3N_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dIpk4oYF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_UvT6Vp3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UvT6Vp3N, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lpNk0EXO, 0, m, &cIf_lpNk0EXO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PaKHIdOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UvT6Vp3N, 0, m, &cDelay_UvT6Vp3N_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dIpk4oYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UvT6Vp3N, 0, m, &cDelay_UvT6Vp3N_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Qt7X7kvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N2Uqf9ST_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Him72Qyw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rW68GGZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n8k6feDD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MWVJNHXW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MWVJNHXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1SckbTFi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_n8k6feDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lpNk0EXO, 1, m, &cIf_lpNk0EXO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Him72Qyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X7TfjCBT, 0, m, &cIf_X7TfjCBT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_N2Uqf9ST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X7TfjCBT, 1, m, &cIf_X7TfjCBT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PRwRKej8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_frDinQET, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_5LplzYxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_frDinQET, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_u7KpzmAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LW4coVUL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_LeOVcIHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Wup7pJtN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_6rrJsjlQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wsvD7Y0K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wsvD7Y0K_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_miqvAJwj, 1, m, &cDelay_miqvAJwj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cr72RIWO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_miqvAJwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_miqvAJwj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_u7KpzmAX, 0, m, &cIf_u7KpzmAX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wsvD7Y0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_miqvAJwj, 0, m, &cDelay_miqvAJwj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cr72RIWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_miqvAJwj, 0, m, &cDelay_miqvAJwj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_So1iOg2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S1CruXJV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lp0LKdzJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_N9Ogq9fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qa1PwlY4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gh3lguCd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qa1PwlY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u7KpzmAX, 1, m, &cIf_u7KpzmAX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gh3lguCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6rrJsjlQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Lp0LKdzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeOVcIHd, 0, m, &cIf_LeOVcIHd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_S1CruXJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeOVcIHd, 1, m, &cIf_LeOVcIHd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Wup7pJtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_159VfxCB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LW4coVUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_159VfxCB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_QGthaGGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_U2jzOkXc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Qz2KygHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_liSVFSfZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3Hi9GSzs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BNsONRcb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BNsONRcb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7XlVqGA0, 1, m, &cDelay_7XlVqGA0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jlc9tN0I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7XlVqGA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7XlVqGA0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QGthaGGR, 0, m, &cIf_QGthaGGR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BNsONRcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7XlVqGA0, 0, m, &cDelay_7XlVqGA0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Jlc9tN0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7XlVqGA0, 0, m, &cDelay_7XlVqGA0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_V934B46d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dlHGB27H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YX6lxk7D_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_lmIJR8r3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xhtv2fJM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3GGNQHRL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Xhtv2fJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QGthaGGR, 1, m, &cIf_QGthaGGR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3GGNQHRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3Hi9GSzs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YX6lxk7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qz2KygHn, 0, m, &cIf_Qz2KygHn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dlHGB27H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qz2KygHn, 1, m, &cIf_Qz2KygHn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_liSVFSfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_twMeG4V8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_U2jzOkXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_twMeG4V8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xcGe1OPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tz10BdLn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Rm01cPRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dyXbrGmx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5iZOOLcZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Xc1hXpho_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Xc1hXpho_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_k8I9mE2U, 1, m, &cDelay_k8I9mE2U_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DS1xCN5c_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_k8I9mE2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_k8I9mE2U, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xcGe1OPF, 0, m, &cIf_xcGe1OPF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Xc1hXpho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_k8I9mE2U, 0, m, &cDelay_k8I9mE2U_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DS1xCN5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_k8I9mE2U, 0, m, &cDelay_k8I9mE2U_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sUZSgngW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_25ccdIC8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mMu2qtdm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pdkv8bvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_914mf1ce_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KerHg32X_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KerHg32X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5iZOOLcZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_914mf1ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xcGe1OPF, 1, m, &cIf_xcGe1OPF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mMu2qtdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rm01cPRO, 0, m, &cIf_Rm01cPRO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_25ccdIC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rm01cPRO, 1, m, &cIf_Rm01cPRO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dyXbrGmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fYgyUPwU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_tz10BdLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fYgyUPwU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_RGDppBTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_AWVKC8Uk_sendMessage(_c, 0, m);
  cMsg_maHzGNjE_sendMessage(_c, 0, m);
  cMsg_kjwtgTbh_sendMessage(_c, 0, m);
  cMsg_qjxQWd6x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zWD1zpIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_AWVKC8Uk_sendMessage(_c, 0, m);
  cMsg_LtQ8WSX7_sendMessage(_c, 0, m);
  cMsg_mqwYIbRJ_sendMessage(_c, 0, m);
  cMsg_MXVsR4qr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aO55ixTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_yWSZTSXa_sendMessage(_c, 0, m);
  cMsg_LtQ8WSX7_sendMessage(_c, 0, m);
  cMsg_qjxQWd6x_sendMessage(_c, 0, m);
  cMsg_deXxS8Vq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_2qWfsJph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_yWSZTSXa_sendMessage(_c, 0, m);
  cMsg_m98OWYDT_sendMessage(_c, 0, m);
  cMsg_kjwtgTbh_sendMessage(_c, 0, m);
  cMsg_cDMT6xyu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BfNDc4Ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_jdZQ8r2d_sendMessage(_c, 0, m);
  cMsg_MXVsR4qr_sendMessage(_c, 0, m);
  cMsg_kd0CsLsu_sendMessage(_c, 0, m);
  cMsg_kjwtgTbh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qaiVRXZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_jdZQ8r2d_sendMessage(_c, 0, m);
  cMsg_cDMT6xyu_sendMessage(_c, 0, m);
  cMsg_LtQ8WSX7_sendMessage(_c, 0, m);
  cMsg_r2ng4u9q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_l1uijWcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6QLNRPfD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UAaMJvrq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Fo5rrgJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6QLNRPfD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UAaMJvrq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oyFcIXKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iIQfYD6J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_02rodNzI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LQvIwzhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iIQfYD6J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_02rodNzI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KUvYqkme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wR1FTbS4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JhvQiDkd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7TWdW8W1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wR1FTbS4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JhvQiDkd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AWVKC8Uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_l1uijWcH_sendMessage(_c, 0, m);
  cMsg_LQvIwzhS_sendMessage(_c, 0, m);
  cMsg_7TWdW8W1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_yWSZTSXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Fo5rrgJH_sendMessage(_c, 0, m);
  cMsg_oyFcIXKn_sendMessage(_c, 0, m);
  cMsg_7TWdW8W1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jdZQ8r2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Fo5rrgJH_sendMessage(_c, 0, m);
  cMsg_LQvIwzhS_sendMessage(_c, 0, m);
  cMsg_KUvYqkme_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8W1HRP82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_swj0To6t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DjwffKBv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kSiJrTQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_swj0To6t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DjwffKBv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EP4QiHkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eE6SxkRv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ue9KezGQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dJxbY3Qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eE6SxkRv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ue9KezGQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZE3QK9Cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ArAd3XTo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yNXeg9xi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Pn9E8bSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ArAd3XTo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yNXeg9xi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LtQ8WSX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_kSiJrTQE_sendMessage(_c, 0, m);
  cMsg_dJxbY3Qz_sendMessage(_c, 0, m);
  cMsg_Pn9E8bSH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_maHzGNjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_kSiJrTQE_sendMessage(_c, 0, m);
  cMsg_EP4QiHkl_sendMessage(_c, 0, m);
  cMsg_ZE3QK9Cb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_m98OWYDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_8W1HRP82_sendMessage(_c, 0, m);
  cMsg_dJxbY3Qz_sendMessage(_c, 0, m);
  cMsg_ZE3QK9Cb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_04o8TVz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N9Ogq9fM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_So1iOg2e_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1gGW8iIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N9Ogq9fM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_So1iOg2e_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_B7wjID5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lmIJR8r3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V934B46d_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nonz2zTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lmIJR8r3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V934B46d_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DZ4jWTFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pdkv8bvZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sUZSgngW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wbfVKPYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pdkv8bvZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sUZSgngW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cDMT6xyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_04o8TVz4_sendMessage(_c, 0, m);
  cMsg_nonz2zTS_sendMessage(_c, 0, m);
  cMsg_wbfVKPYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MXVsR4qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_1gGW8iIx_sendMessage(_c, 0, m);
  cMsg_B7wjID5E_sendMessage(_c, 0, m);
  cMsg_wbfVKPYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qjxQWd6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_1gGW8iIx_sendMessage(_c, 0, m);
  cMsg_nonz2zTS_sendMessage(_c, 0, m);
  cMsg_DZ4jWTFc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_VYmKsHUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3JyAHPr0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yrWPp6IR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_t74wr3lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3JyAHPr0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yrWPp6IR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1EaqcJ7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G8pDnSJt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w7xGtC3Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LYB3SZpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G8pDnSJt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w7xGtC3Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EDbsAbkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rW68GGZV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Qt7X7kvc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bCjIXen3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rW68GGZV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Qt7X7kvc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kjwtgTbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_t74wr3lb_sendMessage(_c, 0, m);
  cMsg_LYB3SZpI_sendMessage(_c, 0, m);
  cMsg_bCjIXen3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_mqwYIbRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_t74wr3lb_sendMessage(_c, 0, m);
  cMsg_1EaqcJ7I_sendMessage(_c, 0, m);
  cMsg_EDbsAbkB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_r2ng4u9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_VYmKsHUE_sendMessage(_c, 0, m);
  cMsg_1EaqcJ7I_sendMessage(_c, 0, m);
  cMsg_bCjIXen3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kd0CsLsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_8W1HRP82_sendMessage(_c, 0, m);
  cMsg_EP4QiHkl_sendMessage(_c, 0, m);
  cMsg_Pn9E8bSH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_deXxS8Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_VYmKsHUE_sendMessage(_c, 0, m);
  cMsg_LYB3SZpI_sendMessage(_c, 0, m);
  cMsg_EDbsAbkB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_CGkO0xNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fEWcskBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_dq42GRCU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jyYKCHSy, 0, m, &cSlice_jyYKCHSy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YuOIaP47_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_jyYKCHSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Iev3Qeq6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Iev3Qeq6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_hkPcOrg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Iev3Qeq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Iev3Qeq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5s6yALMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_MvGz7FwV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LoClgciz, 0, m, &cSlice_LoClgciz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_c5EBjN27_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_LoClgciz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vgKig6N5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vgKig6N5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_KGMX23fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vgKig6N5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_vgKig6N5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yq0obu3O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_c5EBjN27_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ioO9oTZS, 0, m, &cSlice_ioO9oTZS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dq42GRCU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_ioO9oTZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0cGaXWmx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0cGaXWmx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_01gJucX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0cGaXWmx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_0cGaXWmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CU38V6wk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_YuOIaP47_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zMvcR9m3, 0, m, &cSlice_zMvcR9m3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sEwphSnT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_zMvcR9m3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oM1rs3ze_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oM1rs3ze_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_iIjy3gqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oM1rs3ze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_oM1rs3ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Nf2Idi3n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_sEwphSnT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ufqj8Qpz, 0, m, &cSlice_ufqj8Qpz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7dlbICKt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_ufqj8Qpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XsRdPvJC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XsRdPvJC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_HfWwDtXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XsRdPvJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_XsRdPvJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uSSMXVnG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_mziOE4QU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nQoxq4mc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nQoxq4mc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dhPbYCzN, 1, m, &cDelay_dhPbYCzN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bIaxUBLK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_dhPbYCzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dhPbYCzN, m);
  cMsg_gM9UP19Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_nQoxq4mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dhPbYCzN, 0, m, &cDelay_dhPbYCzN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bIaxUBLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dhPbYCzN, 0, m, &cDelay_dhPbYCzN_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_MFyIg3Y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ThUc6uW2, HV_BINOP_SUBTRACT, 0, m, &cBinop_ThUc6uW2_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_OvnJrEfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jJFoToO6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_fDY0ueC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jJFoToO6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_BPK2PezG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MFyIg3Y5, 0, m, &cVar_MFyIg3Y5_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_z0gYwpjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lv7dJlY1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rVlvp7XN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YzAKvw9e_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ThUc6uW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PBr80Ni8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_PBr80Ni8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xAg77AyB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xAg77AyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_y5jr7FOz_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tMSLJYDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dFvO3Lwu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ttAnZBRj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ttAnZBRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PUZIzID6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_dFvO3Lwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OvnJrEfx, 1, m, &cIf_OvnJrEfx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2fbFj1D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fDY0ueC6, 1, m, &cIf_fDY0ueC6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PUZIzID6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OvnJrEfx, 0, m, &cIf_OvnJrEfx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_y5jr7FOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fDY0ueC6, 0, m, &cIf_fDY0ueC6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lv7dJlY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_YzAKvw9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MFyIg3Y5, 0, m, &cVar_MFyIg3Y5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rVlvp7XN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ThUc6uW2, HV_BINOP_SUBTRACT, 1, m, &cBinop_ThUc6uW2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jJFoToO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QyJhiZr5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_7dlbICKt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8t3H2jBp, 0, m, &cSlice_8t3H2jBp_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_8t3H2jBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bwrTTCFg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bwrTTCFg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_hZ7w4ev4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bwrTTCFg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_bwrTTCFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uc0TFB7o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_muuklgMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hOb6nPiC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_s0w7L1Oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jGWCXF4R, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_1LniQsex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FMmZn9FI, 0, m, &cVar_FMmZn9FI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fEWcskBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pqrGIDBx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_LLL5VXaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HuLKtyrO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_b6nui80F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mziOE4QU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gM9UP19Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1jVGjqKD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HuLKtyrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1jVGjqKD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ql57B5RY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_oFVyRbG0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oFVyRbG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aFmyisvH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aFmyisvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mfusku04, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_SDwT3eRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gssWcTvV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XdQ2cTRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ihhNVdUT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Ij1HUBJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GsLUvKtP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_2ixHdDko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tT90hpQG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_IUSvkOm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QaT0GdsJ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MvGz7FwV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xvvdKEtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QaT0GdsJ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MvGz7FwV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_V0GfCozM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VeoMQZLm, 0, m, &cVar_VeoMQZLm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wdI0RgtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QaT0GdsJ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MvGz7FwV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vK4R15ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QaT0GdsJ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MvGz7FwV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_hEj92E5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QaT0GdsJ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MvGz7FwV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yyDEfytq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1ud3xcc1, 0, m, &cVar_1ud3xcc1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OwZEYBxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ZWPOyy8T, 0, m, &cVar_ZWPOyy8T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6aw5Wh64, 0, m, &cVar_6aw5Wh64_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FjXmTUBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_V0GfCozM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XwfsbYXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_WJNpXwDa, 0, m, &cVar_WJNpXwDa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gssWcTvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QaT0GdsJ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MvGz7FwV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_y0z4O6zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_SDwT3eRx, 0, m, &cVar_SDwT3eRx_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_tT90hpQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3wzjlHnZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_4e9ueaY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GolTqN8Z, 0, m, &cVar_GolTqN8Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_yrVjI7fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_V0GfCozM_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_cKqUtYj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1ud3xcc1, 0, m, &cVar_1ud3xcc1_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_t3ElHYV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K2SoT8XX, 0, m, &cVar_K2SoT8XX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5SCO2kUS, 0, m, &cVar_5SCO2kUS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yGq1DcEv, 0, m, &cVar_yGq1DcEv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ftKj1so3, 0, m, &cVar_ftKj1so3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dMLtm9lc, 0, m, &cVar_dMLtm9lc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XtGs1Kns, 0, m, &cVar_XtGs1Kns_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hkPcOrg4, 0, m, &cVar_hkPcOrg4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KGMX23fe, 0, m, &cVar_KGMX23fe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_01gJucX2, 0, m, &cVar_01gJucX2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iIjy3gqg, 0, m, &cVar_iIjy3gqg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HfWwDtXv, 0, m, &cVar_HfWwDtXv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hZ7w4ev4, 0, m, &cVar_hZ7w4ev4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u8WMy3kr_sendMessage);
  cMsg_XwfsbYXC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_BrvpHost_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WJNpXwDa, 0, m, &cVar_WJNpXwDa_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_8CpNk7UX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZWPOyy8T, 0, m, &cVar_ZWPOyy8T_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_gFAdNmvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6aw5Wh64, 0, m, &cVar_6aw5Wh64_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_gVOclxZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JzgJO8lJ, 0, m, &cVar_JzgJO8lJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_mkIKJYlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B5VggnlA, 0, m, &cVar_B5VggnlA_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_dVhEr0PJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_qmajW5lR_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_6K15Xr9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u1586xG0_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YoJeJPyj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LGrcIoHO_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_FVPm3o9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w2VpcfWQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1NgKv6VO_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_MX434jCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Um28SwZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_5s6yALMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IiwQtMmZ, 0, m, &cVar_IiwQtMmZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Nf2Idi3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CGkO0xNp, 0, m, &cVar_CGkO0xNp_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_CU38V6wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_1LniQsex_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_yq0obu3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YR8Sgf1w_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LLL5VXaF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b6nui80F_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_uSSMXVnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tMSLJYDr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2fbFj1D7_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_uc0TFB7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ql57B5RY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_GD6UG4eU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SDwT3eRx, 0, m, &cVar_SDwT3eRx_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_JvjTkjbX, VIf(I0));
    __hv_varread_f(&sVarf_8bDel6Uy, VOf(Bf0));
    __hv_varread_f(&sVarf_MUWmtkEP, VOf(Bf1));
    __hv_varread_f(&sVarf_L7ywj8Vh, VOf(Bf2));
    __hv_varread_f(&sVarf_qtXb8oVL, VOf(Bf3));
    __hv_varread_f(&sVarf_IMKnWbkD, VOf(Bf4));
    __hv_varread_f(&sVarf_xzu0OLAa, VOf(Bf5));
    __hv_varread_f(&sVarf_s5h8TMfd, VOf(Bf6));
    __hv_varwrite_f(&sVarf_24Llj9VO, VIf(I0));
    __hv_varread_f(&sVarf_EV7SjfUb, VOf(Bf7));
    __hv_line_f(&sLine_7QdTuCyK, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_9Fqm8JjX, VOf(Bf9));
    __hv_line_f(&sLine_bfyAvs8n, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_vVauwUYi, VOf(Bf8));
    __hv_line_f(&sLine_GSNMmdQj, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_qtXb8oVL, VIf(Bf11));
    __hv_varread_f(&sVarf_24Llj9VO, VOf(Bf11));
    __hv_line_f(&sLine_RCr9WmBH, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_XNVbNKcB, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_b2XXVnX6, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_IMKnWbkD, VIf(Bf10));
    __hv_line_f(&sLine_QmVUPE3M, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_IZVBTRZZ, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_HcZn2YRe, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_xzu0OLAa, VIf(Bf10));
    __hv_line_f(&sLine_C3fhADNu, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_aW2sooWe, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_GCpU2o8u, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_s5h8TMfd, VIf(Bf10));
    __hv_varwrite_f(&sVarf_EV7SjfUb, VIf(Bf0));
    __hv_varwrite_f(&sVarf_9Fqm8JjX, VIf(Bf1));
    __hv_varwrite_f(&sVarf_vVauwUYi, VIf(Bf2));
    sEnv_process(this, &sEnv_z5kG4mWN, VIf(Bf3), &sEnv_z5kG4mWN_sendMessage);
    sEnv_process(this, &sEnv_dTpUJqTm, VIf(I0), &sEnv_dTpUJqTm_sendMessage);
    __hv_line_f(&sLine_OrgfNzxO, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_a2NXECCt, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_PEdHdOhj, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_wizyGo0R, VOf(Bf3));
    __hv_line_f(&sLine_TDNXfMPO, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_8bDel6Uy, VIf(Bf0));
    __hv_varwrite_f(&sVarf_wizyGo0R, VIf(Bf4));
    __hv_varwrite_f(&sVarf_pIjcumhp, VIf(Bf5));
    __hv_varwrite_f(&sVarf_bhGoFC8h, VIf(Bf6));
    __hv_varread_f(&sVarf_bhGoFC8h, VOf(Bf6));
    __hv_line_f(&sLine_AT31RMNa, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_L7ywj8Vh, VIf(Bf4));
    __hv_varread_f(&sVarf_pIjcumhp, VOf(Bf4));
    __hv_line_f(&sLine_ljgnVXoh, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_MUWmtkEP, VIf(Bf4));
    __hv_varwrite_f(&sVarf_11VZpGbP, VIf(Bf2));
    __hv_varwrite_f(&sVarf_1NQbXSqA, VIf(I1));
    __hv_varread_f(&sVarf_Xr3ZgG2k, VOf(Bf2));
    __hv_varread_f(&sVarf_qqjroiLe, VOf(Bf4));
    __hv_varread_f(&sVarf_OdDXnN1B, VOf(Bf0));
    __hv_varread_f(&sVarf_lbLnlqdn, VOf(Bf5));
    __hv_varread_f(&sVarf_xSOLpGZO, VOf(Bf3));
    __hv_varread_f(&sVarf_rjsjb4ky, VOf(Bf6));
    __hv_varread_f(&sVarf_oiz24wGh, VOf(Bf1));
    __hv_varwrite_f(&sVarf_187MNlQd, VIf(I1));
    __hv_varread_f(&sVarf_rsZ5BTr4, VOf(Bf10));
    __hv_line_f(&sLine_159VfxCB, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_SftBaD2V, VOf(Bf7));
    __hv_line_f(&sLine_twMeG4V8, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_21fk3Pa2, VOf(Bf11));
    __hv_line_f(&sLine_fYgyUPwU, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_lbLnlqdn, VIf(Bf12));
    __hv_varread_f(&sVarf_187MNlQd, VOf(Bf12));
    __hv_line_f(&sLine_kiSijYRw, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_5PzvjFr5, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_thZ50IZE, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_xSOLpGZO, VIf(Bf9));
    __hv_line_f(&sLine_0gg3fXD5, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_VTBoo2xA, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_8jE1x9u4, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_rjsjb4ky, VIf(Bf9));
    __hv_line_f(&sLine_kakFBtiE, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_WjrvsioR, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_frDinQET, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_oiz24wGh, VIf(Bf9));
    __hv_varwrite_f(&sVarf_rsZ5BTr4, VIf(Bf2));
    __hv_varwrite_f(&sVarf_SftBaD2V, VIf(Bf4));
    __hv_varwrite_f(&sVarf_21fk3Pa2, VIf(Bf0));
    sEnv_process(this, &sEnv_BPK2PezG, VIf(Bf5), &sEnv_BPK2PezG_sendMessage);
    sEnv_process(this, &sEnv_z0gYwpjd, VIf(I1), &sEnv_z0gYwpjd_sendMessage);
    __hv_line_f(&sLine_QyJhiZr5, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_1jVGjqKD, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_mfusku04, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Sw6kXKE0, VOf(Bf5));
    __hv_line_f(&sLine_jGWCXF4R, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_Xr3ZgG2k, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Sw6kXKE0, VIf(Bf3));
    __hv_varwrite_f(&sVarf_1euyzL44, VIf(Bf6));
    __hv_varwrite_f(&sVarf_UlqiaWMq, VIf(Bf1));
    __hv_varread_f(&sVarf_UlqiaWMq, VOf(Bf1));
    __hv_line_f(&sLine_pqrGIDBx, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_OdDXnN1B, VIf(Bf3));
    __hv_varread_f(&sVarf_1euyzL44, VOf(Bf3));
    __hv_line_f(&sLine_hOb6nPiC, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_qqjroiLe, VIf(Bf3));
    __hv_varwrite_f(&sVarf_lYIzsiUr, VIf(Bf0));
    __hv_varread_f(&sVarf_1NQbXSqA, VOf(Bf0));
    __hv_line_f(&sLine_GsLUvKtP, VOf(Bf3));
    __hv_varread_f(&sVarf_lYIzsiUr, VOf(Bf2));
    __hv_line_f(&sLine_ihhNVdUT, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_JvjTkjbX, VOf(Bf2));
    __hv_varread_f(&sVarf_11VZpGbP, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
